@@ -662,14 +662,35 @@ cancel c = do
     "\\xcancel" -> ECancel XSlash <$> texToken
     _           -> mzero
 
+textContents :: (Text -> Exp) -> TP [Exp]
+textContents op = char '{' *> manyTill chunk (char '}')
+ where
+   chunk = (op . T.concat <$> many1 textual)
+            <|> textSpaceCommand
+            <|> (char '{' *> (asGroup <$> manyTill chunk (char '}')))
+            <|> innermath
+
+textSpaceCommand :: TP Exp
+textSpaceCommand = try $ do
+  char '\\'
+  choice
+   [ ESpace (2 % 9) <$ char ' '
+   , ESpace ((-1) % 6) <$ char '!'
+   , ESpace (1 % 6) <$ char ','
+   , ESpace (2 % 9) <$ char ':'
+   , ESpace (5 % 18) <$ char ';'
+   , ESpace (2 % 9) <$ char '>'
+   ]
+
 text :: Text -> TP Exp
 text c = do
   op <- maybe mzero return $ M.lookup c textOps
-  char '{'
-  let chunk = ((op . T.concat) <$> many1 textual)
-            <|> (char '{' *> (asGroup <$> manyTill chunk (char '}')))
-            <|> innermath
-  contents <- manyTill chunk (char '}')
+  contents <- textContents op  -- braced
+           <|> ((:[]) <$>      -- nonbraced token
+                (  (op <$> textCommand)
+               <|> textSpaceCommand
+               <|> (op . T.singleton <$> noneOf "\n\t\r \\{}")
+                ))
   spaces
   case contents of
        []   -> return (op "")
