@@ -26,8 +26,8 @@ where
 
 import Text.XML.Light
 import Text.TeXMath.Types
-import Text.TeXMath.Unicode.ToUnicode
 import Data.Generics (everywhere, mkT)
+import Text.TeXMath.Unicode.ToUnicode (toUnicode)
 import Text.TeXMath.Shared (getMMLType, handleDownup,
                             isUppercaseGreek, isRLSequence)
 import Text.TeXMath.Readers.MathML.MMLDict (getMathMLOperator)
@@ -80,7 +80,7 @@ fromForm FPostfix = "postfix"
 fromForm FPrefix  = "prefix"
 
 makeScaled :: Rational -> Element -> Element
-makeScaled x = withAttribute "minsize" p . withAttribute "maxsize" p 
+makeScaled x = withAttribute "minsize" p . withAttribute "maxsize" p
                . setAttribute "stretchy" "true"
   where p = T.pack $ printf "%d%%" (round (100*x) :: Int)
 
@@ -94,7 +94,6 @@ dropTrailing0s t = case T.unsnoc t of -- T.spanEnd does not exist
       Just (_, '.') -> T.snoc x '0'
       _ -> x
 
--- Note: Converts strings to unicode directly, as few renderers support those mathvariants.
 makeText :: TextType -> T.Text -> Element
 makeText a s = case (leadingSp, trailingSp) of
                    (False, False) -> s'
@@ -102,14 +101,15 @@ makeText a s = case (leadingSp, trailingSp) of
                    (False, True)  -> mrow [s', sp]
                    (True,  True)  -> mrow [sp, s', sp]
   where sp = spaceWidth (1/3)
-        s' = withAttribute "mathvariant" attr $ tunode "mtext" $ toUnicode a s
+        s' = withAttribute "mathvariant" (getMMLType a) $
+               -- use Unicode characters as few browsers support the mathvariants
+               tunode "mtext" $ toUnicode a s
         trailingSp = case T.unsnoc s of
           Just (_, c) -> T.any (== c) " \t"
           _           -> False
         leadingSp  = case T.uncons s of
           Just (c, _) -> T.any (== c) " \t"
           _           -> False
-        attr = getMMLType a
 
 makeArray :: Maybe TextType -> [Alignment] -> [ArrayLine] -> Element
 makeArray tt as ls = unode "mtable" $
@@ -144,11 +144,11 @@ setAttribute a v e = e { elAttribs = update (elAttribs e) }
     newAttr = Attr (unqual a) (T.unpack v)
     update [] = [newAttr]
     update (x:xs)
-        | qName (attrKey x) == a = 
+        | qName (attrKey x) == a =
             newAttr : xs
-        | otherwise = 
+        | otherwise =
             x : update xs
-            
+
 accent :: T.Text -> Element
 accent = add_attr (Attr (unqual "accent") "true") .
            tunode "mo"
@@ -187,10 +187,7 @@ insertFunctionApps es' = go es'
 
 showExp :: Maybe TextType -> Exp -> Element
 showExp tt e =
- let toUnicodeMaybe :: TextType -> T.Text -> Maybe T.Text
-     toUnicodeMaybe textStyle t =
-       T.pack <$> mapM (toUnicodeChar . (textStyle,)) (T.unpack t)
-     -- variant node: tries to convert text to appropriate unicode
+ let -- variant node: tries to convert text to appropriate unicode
      -- characters depending on style
      vnode :: String -> T.Text -> Element
      vnode elname t
@@ -201,12 +198,17 @@ showExp tt e =
                 else tunode elname t
            Just TextNormal -> withAttribute "mathvariant" "normal" $
                                 tunode elname t
-           Just textStyle ->
-             case toUnicodeMaybe textStyle t of
-               -- if we can't find unicode equivalents, rely on mathvariant:
-               Nothing -> withAttribute "mathvariant" (getMMLType textStyle) $
-                             tunode elname t
-               Just t' -> tunode elname t'
+           Just TextBold
+             | elname == "mi" && not (isUppercaseGreek t) -- #255, #280
+               -> withAttribute "mathvariant" "bold-italic" $
+                     tunode elname (toUnicode TextBoldItalic t)
+             | otherwise
+               -> withAttribute "mathvariant" "bold" $
+                     tunode elname (toUnicode TextBold t)
+           Just textStyle -> withAttribute "mathvariant" (getMMLType textStyle) $
+                              -- we use unicode chars because browsers don't
+                              -- completely support mathvariant:
+                              tunode elname (toUnicode textStyle t)
   in case e of
    ENumber x        -> vnode "mn" x
    EGrouped [x]     -> showExp tt x
